
Multiformats: Python implementation of multiformat protocols
============================================================

A Python implementation of the `multiformat protocols <https://multiformats.io/>`_.

GitHub repo: https://github.com/hashberg-io/multiformats


.. toctree::
    :maxdepth: 3
    :caption: Contents

    getting-started
    varint
    multicodec
    multibase
    multihash
    cid
    multiaddr
    implementation-report

.. include:: api-toc.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
